@@ -1,6 +1,5 @@
 var config = {
 
-  development: {
     host: "https://localhost:3000",
     appId: "d8fcffc5-d1ab-40f1-ac63-d2643d7b9464",
     appKey: "5fc02522e60958787b8298067513c5f4b44ca78a",
@@ -9,6 +8,11 @@ var config = {
       port: 28015
     },
 
+    ws:{
+       url: 'ws://128.199.230.199/ws',
+       realm: 'realm1'
+    },
+
     oauth: {
       facebook: {
         provoider: 'facebook',
@@ -29,30 +33,25 @@ var config = {
         name: "mysql",
         driver: "com.mysql.jdbc.Driver",
         url: "jdbc:mysql://db.codeunbug.com:3306/rmut_expert_db",
-        user: "test",
-        password: "If1C5B13eeNWvyCr"
+        user: "xx",
+        password: "xx"
       },
       {
         name: "mssql",
         driver: "com.microsoft.sqlserver.jdbc.SQLServerDriver",
         url: "jdbc:sqlserver://202.44.34.86:1433;databaseName=RiceDB",
-        user: "riceuser",
-        password: "l2ice2015"
+        user: "xx",
+        password: "xx"
       },
       {
         name: "oracle",
         driver: "oracle.jdbc.OracleDriver",
         url: "jdbc:oracle:thin:@25.32.200.27:1521:gl3d",
-        user: "wzeB505",
-        password: "acreporter"
+        user: "xx",
+        password: "xx"
       }
     ]
-  },
-
-  production: {
-
-  }
-
+  
 };
 
-module.exports = config[process.env.NODE_ENV || 'development'];
\ No newline at end of file
+module.exports = config;
\ No newline at end of file
