@@ -18,7 +18,7 @@ var logger = require('winston');
 var async = require('async');
 var fscan = require('./../common/fscan');
 const config = require(process.cwd() + '/config/config');
-var passport = require('passport');
+//var passport = require('passport');
 
 
 var loadRouter = function (app, nylon_path, prefix, wd, rd, routes, callback) {
